@@ -8,12 +8,12 @@ BEGIN {
 
 require 'module_tools.pl';
 
-my( $HAS_Spreadsheet_ParseExcel, $HAS_Compress_Raw_Zlib, $HAS_Spreadsheet_XLSX);
+my( $HAS_Spreadsheet_ParseExcel, $HAS_Compress_Raw_Zlib, $HAS_Spreadsheet_ParseXLSX);
 
 # check if we need to do anything
 
 ($HAS_Spreadsheet_ParseExcel, 
  $HAS_Compress_Raw_Zlib, 
- $HAS_Spreadsheet_XLSX) = check_modules(0);
+ $HAS_Spreadsheet_ParseXLSX) = check_modules(0);
 
 install_modules() unless $HAS_Compress_Raw_Zlib;
